@@ -41,5 +41,13 @@ module Rabbit
         "<p>\n#{super}\n</p>"
       end
     end
+
+    class WaitBlock
+      include ContainerElement
+
+      def have_wait_tag?
+        true
+      end
+    end
   end
 end
