@@ -140,7 +140,7 @@ module Rabbit
     end
 
     module Control
-      REDRAW_KEYS = [
+      CLEAR_SLIDE_KEYS = [
         Gdk::Keyval::GDK_l,
       ]
 
@@ -181,6 +181,10 @@ module Rabbit
       RESET_ADJUSTMENT_KEYS = [
         Gdk::Keyval::GDK_a,
       ]
+
+      RESET_TIMER_KEYS = [
+        Gdk::Keyval::GDK_t,
+      ]
     end
   end
 end
