@@ -102,7 +102,9 @@ module Rabbit
         end
 
         def create_pango_context
-          create_context(StringIO.new).create_pango_layout.context
+          context = create_context(StringIO.new).create_pango_layout.context
+          set_font_resolution(context)
+          context
         end
 
         def find_surface(filename, output=nil)
