@@ -1,3 +1,4 @@
+require 'tempfile'
 require 'nkf'
 
 module Rabbit
@@ -32,7 +33,10 @@ module Rabbit
             unless silent
               STDERR.puts([Time.now - before, normalized_path].inspect)
             end
-          rescue LoadError
+          rescue LoadError, RuntimeError # Should be changed to Gtk::InitError?
+            if $!.is_a?(RuntimeError)
+              raise if /\ACannot open display:\s*\d*\z/ !~ $!.message
+            end
             unless silent
               STDERR.puts(path)
               STDERR.puts($!.message)
@@ -142,6 +146,14 @@ module Rabbit
       /cygwin|mingw|mswin32|bccwin32/.match(RUBY_PLATFORM) ? true : false
     end
 
+    def quartz?
+      if Gdk.respond_to?(:windowing_quartz?)
+        Gdk.windowing_quartz?
+      else
+        !windows? and !Gdk.windowing_x11?
+      end
+    end
+
     def move_to(base, target)
       window = base.window
       screen = window.screen
@@ -213,17 +225,17 @@ module Rabbit
       end
     end
 
-    def extract_four_dimensions(params)
+    def extract_four_way(params)
       [params[:top], params[:right], params[:bottom], params[:left]]
     end
 
-    def parse_four_dimensions(*values)
+    def parse_four_way(*values)
       if values.is_a?(Array) and values.size == 1 and
           (values.first.is_a?(Array) or values.first.is_a?(Hash))
         values = values.first
       end
       if values.is_a?(Hash)
-        extract_four_dimensions(values)
+        extract_four_way(values)
       else
         case values.size
         when 1
@@ -261,6 +273,15 @@ module Rabbit
       output = [message, output] if message
       p output
     end
+
+    def stringify_hash_key!(hash)
+      dupped_hash = hash.dup
+      hash.clear
+      dupped_hash.each do |key, value|
+        hash[key.to_s] = value
+      end
+      hash
+    end
   end
 
   module SystemRunner
@@ -390,4 +411,49 @@ module Rabbit
       NKF.nkf("-eW", str)
     end
   end
+
+  module ModuleLoader
+    LOADERS = {}
+
+    class << self
+      def extend_object(object)
+        super
+        LOADERS[object] = []
+      end
+    end
+
+    def loaders
+      LOADERS.find do |loader, value|
+        self.ancestors.find {|ancestor| ancestor == loader}
+      end[1]
+    end
+
+    def unshift_loader(loader)
+      loaders.unshift(loader)
+    end
+
+    def push_loader(loader)
+      loaders.push(loader)
+    end
+
+    def find_loader(*args)
+      loaders.find do |loader|
+        loader.match?(*args)
+      end
+    end
+  end
+
+  module TemporaryFile
+    module_function
+    def make(content=nil, prefix=nil)
+      base = ["rabbit", prefix].compact.join("-")
+      temp = Tempfile.new(base)
+      if content
+        temp.binmode
+        temp.print(content)
+        temp.close
+      end
+      yield temp
+    end
+  end
 end
